<?php


/**
 * @file
 * Hooks provided by the Juicebox module.
 */


/**
 * Allow modules to alter the Juicebox gallery object used to build gallery
 * embed code and XML before rendering.
 *
 * @param object $juicebox
 *   A Juicebox gallery object that contains the gallery which is going to be
 *   rendered. This object can be further manipulated using any methods from
 *   JuiceboxGalleryDrupalInterface (which includes JuiceboxGalleryInterface).
 * @param mixed $data
 *   The raw Drupal data that was used to build this gallery. Provided for
 *   context.
 */
function hook_juicebox_gallery_alter($juicebox, $data) {
  // Only make changes to galleries that use the field formatter
  // (checking other $id_args can also allow targeting a specific gallery).
  $id_args = $juicebox->getIdArgs();
  if ($id_args[0] == 'field') {
    foreach ($juicebox->getImages() as $key => $image) {
      // Add some static text to all title values and write changes back.
      $image['title'] .= ' &copy; 2014';
      $juicebox->updateImage($key, $image['src_data'], $image['title'], $image['caption']);
    }
  }
}


/**
 * Allow modules to alter the classes that are instantiated when a Juicebox
 * object is created.
 *
 * @param array $classes
 *   An associative array containing the class names that will be instantiated:
 *   - gallery: A gallery object dependency (implementing
 *     JuiceboxGalleryInterface) that's used to create the script and markup
 *     outputs of a Juicebox gallery.
 *   - juicebox: A Juicebox gallery wrapper (implementing
 *     JuiceboxGalleryWrapperInterface) that will be used to wrap/decorate the
 *     gallery object with Drupal-specific logic and structures.
 * @param array $library
 *   Juicebox javascript library data as provided through Libraries API.
 *   Provided for context.
 *
 * @see juicebox()
 */
function hook_juicebox_classes_alter(&$classes, $library) {
  // Provide custom (global) overrides to a Juicebox library.
  $classes['juicebox'] = 'MyJuiceboxGalleryWrapper';
  // Swap out the gallery dependency object because some future Juicebox
  // javascript library requires different embed or XML output.
  if (!empty($library['version']) && $library['version'] == 'Pro 12.3') {
    $classes['gallery'] = 'FutureJuiceboxGallery';
  }
}
